==> gas_dynamics-0.3.7-py3-none-any.whl: gas_dynamics/__init__.py <==
#!usr/bin/env

#import isentropic functions and stagnation relations
from gas_dynamics.standard.standard import ( 
  sonic_velocity,
  stagnation_pressure,
  stagnation_temperature,
  stagnation_pressure_ratio,
  stagnation_temperature_ratio,
  stagnation_density_ratio,
  stagnation_ratio,
  stagnation_ratio_table,
  mach_from_pressure_ratio,
  mach_from_temperature_ratio,
  pressure_from_mach_ratio,
  temperature_from_mach_ratio,
  entropy_produced,
  mach_area_star_ratio,
  mach_area_ratio,
  mach_from_area_ratio,
  mass_flux_max,
  mass_flux,
  plot_stagnation_ratios )

#import shock functions
from gas_dynamics.shocks.shocks import (
  shock_mach,
  shock_mach_before,
  shock_pressure_ratio,
  shock_mach_from_pressure_ratio,
  shock_temperature_ratio,
  shock_dv_a, 
  shock_stagnation_pressure_ratio, 
  shock_flow_deflection, 
  shock_angle, 
  shock_mach_given_angles, 
  shock_oblique_charts,
  shock_tables, 
  shock_flow_deflection_from_machs)

from gas_dynamics.prandtl_meyer.prandtl_meyer import (
  prandtl_meyer_turn, 
  prandtl_meyer_mach )

from gas_dynamics.fanno.fanno import (
  stagnation_enthalpy,
  fanno_temperature_ratio,
  fanno_pressure_ratio,
  fanno_density_ratio,
  fanno_stagnation_pressure_ratio,
  fanno_temperature_star_ratio,
  fanno_pressure_star_ratio,
  fanno_density_star_ratio,
  fanno_velocity_star_ratio,
  fanno_parameter,
  fanno_parameter_max,
  mach_from_fanno)

from gas_dynamics.rayleigh.rayleigh import(
  rayleigh_pressure_ratio,
  rayleigh_temperature_ratio,
  rayleigh_density_ratio,
  rayleigh_stagnation_temperature_ratio,
  rayleigh_stagnation_pressure_ratio,
  rayleigh_mach_from_pressure_ratio,
  rayleigh_mach_from_temperature_ratio,
  rayleigh_mach_from_stagnation_temperature_ratio,
  rayleigh_mach_from_stagnation_pressure_ratio,
  rayleigh_pressure_star_ratio,
  rayleigh_temperature_star_ratio,
  rayleigh_density_star_ratio,
  rayleigh_stagnation_pressure_star_ratio,
  rayleigh_stagnation_temperature_star_ratio,
  rayleigh_heat_flux)

from gas_dynamics.fluids import fluid

#from .fanno import func1,
#from .rayleigh func 1

==> gas_dynamics-0.4.0-py3-none-any.whl: gas_dynamics/__init__.py <==
#!usr/bin/env

#import isentropic functions and stagnation relations
from gas_dynamics.standard.standard import ( 
  sonic_velocity,
  stagnation_pressure,
  stagnation_temperature,
  stagnation_pressure_ratio,
  stagnation_temperature_ratio,
  stagnation_density_ratio,
  stagnation_ratio,
  stagnation_ratio_table,
  mach_from_pressure_ratio,
  mach_from_temperature_ratio,
  pressure_from_mach_ratio,
  temperature_from_mach_ratio,
  entropy_produced,
  mach_area_star_ratio,
  mach_area_ratio,
  mach_from_area_ratio,
  mass_flux_max,
  mass_flux,
  plot_stagnation_ratios )

#import shock functions
from gas_dynamics.shocks.shocks import (
  shock_mach,
  shock_mach_before,
  shock_pressure_ratio,
  shock_mach_from_pressure_ratio,
  shock_temperature_ratio,
  shock_dv_a, 
  shock_stagnation_pressure_ratio, 
  shock_flow_deflection, 
  shock_angle, 
  shock_mach_given_angles, 
  shock_oblique_charts,
  shock_tables, 
  shock_flow_deflection_from_machs)

from gas_dynamics.prandtl_meyer.prandtl_meyer import (
  prandtl_meyer_angle_from_mach, 
  prandtl_meyer_mach_from_angle,
  mach_wave_angle )

from gas_dynamics.fanno.fanno import (
  stagnation_enthalpy,
  fanno_temperature_ratio,
  fanno_pressure_ratio,
  fanno_density_ratio,
  fanno_stagnation_pressure_ratio,
  fanno_temperature_star_ratio,
  fanno_pressure_star_ratio,
  fanno_density_star_ratio,
  fanno_velocity_star_ratio,
  fanno_parameter,
  fanno_parameter_max,
  mach_from_fanno)

from gas_dynamics.rayleigh.rayleigh import(
  rayleigh_pressure_ratio,
  rayleigh_temperature_ratio,
  rayleigh_density_ratio,
  rayleigh_stagnation_temperature_ratio,
  rayleigh_stagnation_pressure_ratio,
  rayleigh_mach_from_pressure_ratio,
  rayleigh_mach_from_temperature_ratio,
  rayleigh_mach_from_stagnation_temperature_ratio,
  rayleigh_mach_from_stagnation_pressure_ratio,
  rayleigh_pressure_star_ratio,
  rayleigh_temperature_star_ratio,
  rayleigh_density_star_ratio,
  rayleigh_stagnation_pressure_star_ratio,
  rayleigh_stagnation_temperature_star_ratio,
  rayleigh_heat_flux)

from gas_dynamics.fluids import fluid
